[![PyPI Downloads](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fpypistats.org%2Fapi%2Fpackages%2Fpycracks%2Frecent&query=%24.data.last_month&style=for-the-badge&label=Installations%20%2F%20Month)](https://pypistats.org/packages/pycracks)
[![PyPI Version](https://img.shields.io/pypi/v/pycracks?style=for-the-badge)](https://pypi.org/project/PyCracks/)
![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/elc/pycracks/build.yml?style=for-the-badge&logo=github&label=CICD)
[![Coveralls branch](https://img.shields.io/coverallsCoverage/github/ELC/pycracks?branch=master&style=for-the-badge)](https://coveralls.io/github/ELC/pycracks)
[![FOSSA Status](https://img.shields.io/badge/LICENSE%20SCAN-PASSING-CD2956?style=for-the-badge&logo=fossa)](https://app.fossa.com/projects/git%2Bgithub.com%2FELC%2Fpycracks)

# Pycracks

💢🔍 breaking change detection in Python - Compatible with Semantic Version and Semantic Release

## Usage

## Installation

## F.A.Q.

## License

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2FELC%2Fpycracks.svg?type=large)](https://app.fossa.com/projects/git%2Bgithub.com%2FELC%2Fpycracks)
